summaryrefslogtreecommitdiff
path: root/cesar/ce/rx/bitloading/inc/transition.h
diff options
context:
space:
mode:
Diffstat (limited to 'cesar/ce/rx/bitloading/inc/transition.h')
-rw-r--r--cesar/ce/rx/bitloading/inc/transition.h39
1 files changed, 20 insertions, 19 deletions
diff --git a/cesar/ce/rx/bitloading/inc/transition.h b/cesar/ce/rx/bitloading/inc/transition.h
index 968c8ed8c6..06983ee666 100644
--- a/cesar/ce/rx/bitloading/inc/transition.h
+++ b/cesar/ce/rx/bitloading/inc/transition.h
@@ -21,37 +21,38 @@
BEGIN_DECLS
/**
* Handle reception of channel_data_received in IDLE state.
* \param ce_rx the CE RX context.
* \param sta the corresponding sta.
- * \param chan_data the data associated to the event (channel data).
+ * \param data the data associated to the event.
* \return the next state.
- *
- * It must be based on sound frames.
- *
- * Just copy the noise NRJ to initialize the mean/sum.
*/
ce_rx_bl_fsm_branch_t
-ce_rx_bl__IDLE__channel_data_received (ce_rx_t *ce_rx, sta_t *sta,
- ce_rx_bitloading_fsm_event_param_t
- chan_data);
+ce_rx_bl__IDLE__measure_received (ce_rx_t *ce_rx, sta_t *sta,
+ ce_rx_bitloading_fsm_event_param_t data);
/**
* Handle reception of channel_data_received in INITIAL state.
* \param ce_rx the CE RX context.
* \param sta the corresponding sta.
- * \param chan_data the data associated to the event (channel data).
+ * \param data the data associated to the event.
+ * \return the next state.
+ */
+ce_rx_bl_fsm_branch_t
+ce_rx_bl__INITIAL__measure_received (ce_rx_t *ce_rx, sta_t *sta,
+ ce_rx_bitloading_fsm_event_param_t data);
+
+/**
+ * Handle reception of measure_received in TRACKING state.
+ * \param ce_rx the CE RX context.
+ * \param sta the corresponding sta.
+ * \param data the data associated to the event.
* \return the next state.
- *
- * It must be based on sound frames.
- *
- * If not the last one, just copy the noise NRJ to initialize the mean/sum.
- * Otherwise, compute initial tone map.
*/
ce_rx_bl_fsm_branch_t
-ce_rx_bl__INITIAL__channel_data_received (ce_rx_t *ce_rx, sta_t *sta,
- ce_rx_bitloading_fsm_event_param_t
- chan_data);
+ce_rx_bl__TRACKING__measure_received (ce_rx_t *ce_rx, sta_t *sta,
+ ce_rx_bitloading_fsm_event_param_t
+ data);
END_DECLS
@@ -21,37 +21,38 @@
BEGIN_DECLS
/**
- * Handle reception of channel_data_received in IDLE state.
+ * Handle reception of measure_received in IDLE state.
* \param ce_rx the CE RX context.
* \param sta the corresponding sta.
@@ -21,37 +21,38 @@
/**
- * Handle reception of channel_data_received in INITIAL state.
+ * Handle reception of measure_received in INITIAL state.
* \param ce_rx the CE RX context.
* \param sta the corresponding sta.